@@ -34,7 +34,7 @@ public:
     LockScreen();
 
     static bool isLocked();
-    static bool isPortrait();
+    //static bool isPortrait();
     bool show();
     bool hide();
     static bool Debug;
@@ -54,21 +54,23 @@ private:
     QString m_tklockState;
 
     void startUpdate();
-    void stopUpdate();
 
     QString m_BkgPath;
     void setSizeAndPosition();
 
 private slots:
+    void stopUpdate();
     LsWidget* createWidget(QString type, QString name);
     void onDisplayStateChangedSlot(QString displayState);
     void onTkLockChanged(QString locked);
     void onCallStateChanged(QString);
 #ifdef Q_WS_MAEMO_5
-    void onOrientationChanged(QDBusMessage);
+    //void onOrientationChanged(QDBusMessage);
+    void onOrientationChanged(int);
     void onIncomingCallSlot(QDBusMessage);
     void onAlarmDialogStatusChanged(QDBusMessage);
 #endif
+
 };
 
 #endif // LOCKSCREEN_H
