@@ -19,7 +19,7 @@
 #include <QApplication>
 #include <QDesktopWidget>
 
-bool LsWidget::m_Portrait;
+//bool LsWidget::m_Portrait;
 
 LsWidget::LsWidget(QString name)
 {
@@ -198,6 +198,11 @@ void LsWidget::update()
 }
 
 bool LsWidget::isPortrait()
+{
+    return QApplication::desktop()->width() < QApplication::desktop()->height();
+}
+
+/*bool LsWidget::isPortrait()
 {
     return LsWidget::m_Portrait;
 }
@@ -205,7 +210,7 @@ bool LsWidget::isPortrait()
 void LsWidget::setPortrait(bool portrait)
 {
     LsWidget::m_Portrait = portrait;
-}
+}*/
 
 void LsWidget::setSizeAndPosition(QSize defaultSize, QPoint defaultPos)
 {
